# lager-cli
Lager Command Line Interface

## Development

### Installation for development purposes

```
python3 -m venv $(< .venv)
source $(< .venv)/bin/activate
pip install --editable .
```

With the virtualenv sourced, the `lager` executable should be available.